@@ -36,7 +36,7 @@
 #include "gsm_pkexec.h"
 #include "cgroups.h"
 
-static GtkWidget *renice_dialog = NULL;
+static GtkDialog *renice_dialog = NULL;
 static gint new_nice_value = 0;
 
 
@@ -56,7 +56,7 @@ kill_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 void
 procdialog_create_kill_dialog (GsmApplication *app, int signal)
 {
-    GtkWidget *kill_alert_dialog;
+    GtkMessageDialog *kill_alert_dialog;
     gchar *primary, *secondary, *button_text;
     struct ProcActionArgs *kargs;
 
@@ -70,52 +70,82 @@ procdialog_create_kill_dialog (GsmApplication *app, int signal)
         // get the last selected row
         gtk_tree_selection_selected_foreach (app->selection, get_last_selected,
                                          &selected_process);
-        if (signal == SIGKILL) {
-            /*xgettext: primary alert message for killing single process*/
-            primary = g_strdup_printf (_("Are you sure you want to kill the selected process “%s” (PID: %u)?"),
-                                       selected_process->name,
-                                       selected_process->pid);
-        } else {
-            /*xgettext: primary alert message for ending single process*/
-            primary = g_strdup_printf (_("Are you sure you want to end the selected process “%s” (PID: %u)?"),
-                                       selected_process->name,
-                                       selected_process->pid);
+        switch (signal) {
+            case SIGKILL:
+                /*xgettext: primary alert message for killing single process*/
+                primary = g_strdup_printf (_("Are you sure you want to kill the selected process “%s” (PID: %u)?"),
+                                           selected_process->name,
+                                           selected_process->pid);
+                break;
+            case SIGTERM:
+                /*xgettext: primary alert message for ending single process*/
+                primary = g_strdup_printf (_("Are you sure you want to end the selected process “%s” (PID: %u)?"),
+                                           selected_process->name,
+                                           selected_process->pid);
+                break;
+            default: // SIGSTOP
+                /*xgettext: primary alert message for stopping single process*/
+                primary = g_strdup_printf (_("Are you sure you want to stop the selected process “%s” (PID: %u)?"),
+                                           selected_process->name,
+                                           selected_process->pid);
+                break;
         }
     } else {
-        if (signal == SIGKILL) {
-            /*xgettext: primary alert message for killing multiple processes*/
-            primary = g_strdup_printf (ngettext("Are you sure you want to kill the selected process?", "Are you sure you want to kill the %d selected processes?", selected_count),
-                                       selected_count);
-        } else {
-            /*xgettext: primary alert message for ending multiple processes*/
-            primary = g_strdup_printf (ngettext("Are you sure you want to end the selected process?", "Are you sure you want to end the %d selected processes?", selected_count),
-                                       selected_count);
+        switch (signal) {
+            case SIGKILL:
+                /*xgettext: primary alert message for killing multiple processes*/
+                primary = g_strdup_printf (ngettext("Are you sure you want to kill the selected process?", 
+                                                    "Are you sure you want to kill the %d selected processes?", selected_count),
+                                           selected_count);
+            break;
+            case SIGTERM:
+                /*xgettext: primary alert message for ending multiple processes*/
+                primary = g_strdup_printf (ngettext("Are you sure you want to end the selected process?", 
+                                                    "Are you sure you want to end the %d selected processes?", selected_count),
+                                           selected_count);
+            break;
+            default: // SIGSTOP
+                /*xgettext: primary alert message for stopping multiple processes*/
+                primary = g_strdup_printf (ngettext("Are you sure you want to stop the selected process?", 
+                                                    "Are you sure you want to stop the %d selected processes?", selected_count),
+                                           selected_count);
+            break;
         }
     }
     
-    if ( signal == SIGKILL ) {
-        /*xgettext: secondary alert message*/
-        secondary = _("Killing a process may destroy data, break the "
-                      "session or introduce a security risk. "
-                      "Only unresponsive processes should be killed.");
-        button_text = ngettext("_Kill Process", "_Kill Processes", selected_count);
-    } else {
-        /*xgettext: secondary alert message*/
-        secondary = _("Killing a process may destroy data, break the "
-                      "session or introduce a security risk. "
-                      "Only unresponsive processes should be killed.");
-        button_text = ngettext("_End Process", "_End Processes", selected_count);
+    switch (signal) {
+        case SIGKILL:
+            /*xgettext: secondary alert message*/
+            secondary = _("Killing a process may destroy data, break the "
+                          "session or introduce a security risk. "
+                          "Only unresponsive processes should be killed.");
+            button_text = ngettext("_Kill Process", "_Kill Processes", selected_count);
+            break;
+        case SIGTERM:
+            /*xgettext: secondary alert message*/
+            secondary = _("Ending a process may destroy data, break the "
+                          "session or introduce a security risk. "
+                          "Only unresponsive processes should be ended.");
+            button_text = ngettext("_End Process", "_End Processes", selected_count);
+            break;
+        default: // SIGSTOP
+            /*xgettext: secondary alert message*/
+            secondary = _("Stopping a process may destroy data, break the "
+                          "session or introduce a security risk. "
+                          "Only unresponsive processes should be stopped.");
+            button_text = ngettext("_Stop Process", "_Stop Processes", selected_count);
+            break;
     }
-    
-    kill_alert_dialog = gtk_message_dialog_new (GTK_WINDOW (app->main_window),
+
+    kill_alert_dialog = GTK_MESSAGE_DIALOG (gtk_message_dialog_new (GTK_WINDOW (app->main_window),
                                                 static_cast<GtkDialogFlags>(GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
                                                 GTK_MESSAGE_WARNING,
                                                 GTK_BUTTONS_NONE,
                                                 "%s",
-                                                primary);
+                                                primary));
     g_free (primary);
 
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (kill_alert_dialog),
+    gtk_message_dialog_format_secondary_text (kill_alert_dialog,
                                               "%s",
                                               secondary);
 
@@ -130,17 +160,17 @@ procdialog_create_kill_dialog (GsmApplication *app, int signal)
     g_signal_connect (G_OBJECT (kill_alert_dialog), "response",
                       G_CALLBACK (kill_dialog_button_pressed), kargs);
 
-    gtk_widget_show_all (kill_alert_dialog);
+    gtk_widget_show_all (GTK_WIDGET (kill_alert_dialog));
 }
 
 static void
 renice_scale_changed (GtkAdjustment *adj, gpointer data)
 {
-    GtkWidget *label = GTK_WIDGET (data);
+    GtkLabel *label = GTK_LABEL (data);
 
     new_nice_value = int(gtk_adjustment_get_value (adj));
     gchar* text = g_strdup(procman::get_nice_level_with_priority (new_nice_value));
-    gtk_label_set_text (GTK_LABEL (label), text);
+    gtk_label_set_text (label, text);
     g_free(text);
 
 }
@@ -164,8 +194,8 @@ procdialog_create_renice_dialog (GsmApplication *app)
 {
     ProcInfo *info;
     
-    GtkWidget *label;
-    GtkWidget *priority_label;
+    GtkLabel *label;
+    GtkLabel *priority_label;
     GtkAdjustment *renice_adj;
     GtkBuilder *builder;
     gchar     *text;
@@ -183,7 +213,7 @@ procdialog_create_renice_dialog (GsmApplication *app)
     builder = gtk_builder_new();
     gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/renice.ui", NULL);
 
-    renice_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "renice_dialog"));
+    renice_dialog = GTK_DIALOG (gtk_builder_get_object (builder, "renice_dialog"));
     if ( selected_count == 1 ) {
         dialog_title = g_strdup_printf (_("Change Priority of Process “%s” (PID: %u)"),
                                         info->name, info->pid);
@@ -204,15 +234,15 @@ procdialog_create_renice_dialog (GsmApplication *app)
 
     new_nice_value = 0;
     
-    priority_label =  GTK_WIDGET (gtk_builder_get_object (builder, "priority_label"));
-    gtk_label_set_label (GTK_LABEL(priority_label), procman::get_nice_level_with_priority (info->nice));
+    priority_label =  GTK_LABEL (gtk_builder_get_object (builder, "priority_label"));
+    gtk_label_set_label (priority_label, procman::get_nice_level_with_priority (info->nice));
 
     text = g_strconcat("<small><i><b>", _("Note:"), "</b> ",
                        _("The priority of a process is given by its nice value. A lower nice value corresponds to a higher priority."),
                        "</i></small>", NULL);
-    label = GTK_WIDGET (gtk_builder_get_object (builder, "note_label"));
-    gtk_label_set_label (GTK_LABEL(label), _(text));
-    gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+    label = GTK_LABEL (gtk_builder_get_object (builder, "note_label"));
+    gtk_label_set_label (label, _(text));
+    gtk_label_set_line_wrap (label, TRUE);
     g_free (text);
 
     g_signal_connect (G_OBJECT (renice_dialog), "response",
@@ -221,7 +251,7 @@ procdialog_create_renice_dialog (GsmApplication *app)
                       G_CALLBACK (renice_scale_changed), priority_label);
 
     gtk_window_set_transient_for (GTK_WINDOW (renice_dialog), GTK_WINDOW (GsmApplication::get()->main_window));
-    gtk_widget_show_all (renice_dialog);
+    gtk_widget_show_all (GTK_WIDGET (renice_dialog));
 
     gtk_builder_connect_signals (builder, NULL);
 
